<?php
require_once("assertionChecking.interface.php");
require_once 'policy.class.php';
    /**
     * Class that checks if a given sir assertion is valid.
     */
    class sirAssertionChecking implements IAssertionChecking {
        private $assertion;
        private $policy;
        private $personId;
        private $error;

        /**
         * Load the policies from a  given file.
         * @param <type> $rulesf The archive file with the policy.
         */
        public function __construct($rulesf = "config/policies.xml") {
             $this->error = false;
            if(0==sizeof($this->getPolicy($rulesf))) {
                error_log("ERROR EXTRAYENDO POLÍTICAS");
                $this->error = true;
            }
        }

        /**
         * Function that checks if the assertion is authorized
         * @param array $assertion Assertion to check
         * @return bool. True if the policy matches the assertion.
         */
        public function checkAssertion($assertion) {
            $this->assertion = $assertion;
            $dev = false;
            if($this->matchRules()!=false) {
                $this->personId = $this->assertion['sPUC'];           
                $dev = true;
            }
            return $dev;
        }
        /**
         * Function that decides if the assertion matches the policy,
         * @param <type> $assertion
         * @return bool. True if the policy matches the assertion.
         */
        protected function matchRules() {
            $dev = true;
            if(sizeof($this->policy)>0) {
                foreach ($this->policy as $pol) {
                    $dev = $dev && $pol->checkPolicy($this->assertion);
                }
            }else {
                $dev = false;
            }
            return $dev;
        }

            /**
         * Function that loads the Policy from a given file
         * @param <type> $rulesfile File of the policy
         * @return AssertionPolicy. The Policy.
         */
        protected function getPolicy($rulesfile) {
      //      error_log('sirAssertionChecking.getPolicy');
            $this->policy=array();
            $xml = simplexml_load_file($rulesfile);
            if(strcmp($xml->getName(),"AssertionList")==0) {
                $i=0;
                while($i<sizeof($xml->children())) {
                    $arr = $xml->children();
                    if(strcmp("sir",$arr[$i]['type'])==0) {
                        $j=0;
                        while($j<sizeof($arr[$i]->Policies->children())) {
                            $arr2 =  $arr[$i]->Policies->Policy;
                            $this->policy[$j] = new AssertionPolicy($arr2[$j]);
                            $j++;
                        }
                    }
                    $i++;
                }
            }
            return $this->policy;
        }


                   /**
         * Person Id getter
         * @return String: The scope.
         */
        public function getPersonId() {
            return $this->personId[0];
        }
   
        public function getError() {
            return $this->error;
        }

         

    }
    ?>